==> apache-camel-quarkus-3.27.1-src.zip: camel-quarkus-3.27.1/extensions/opentelemetry2/runtime/src/main/java/org/apache/camel/quarkus/component/opentelemetry2/OpenTelemetry2TracerProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.opentelemetry2;

import io.quarkus.arc.DefaultBean;
import io.quarkus.opentelemetry.runtime.config.runtime.OTelRuntimeConfig;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Inject;
import jakarta.inject.Singleton;
import org.apache.camel.opentelemetry2.OpenTelemetryTracer;

@Singleton
public class OpenTelemetry2TracerProducer {

    @Inject
    CamelOpenTelemetry2Config config;

    @Inject
    OTelRuntimeConfig oTelRuntimeConfig;

    @Produces
    @Singleton
    @DefaultBean
    public OpenTelemetryTracer getOpenTelemetry() {
        if (!oTelRuntimeConfig.sdkDisabled()) {
            OpenTelemetryTracer openTelemetryTracer = new OpenTelemetryTracer();
            if (config.excludePatterns().isPresent()) {
                openTelemetryTracer.setExcludePatterns(config.excludePatterns().get());
            }

            if (config.traceProcessors()) {
                openTelemetryTracer.setTraceProcessors(config.traceProcessors());
            }

            return openTelemetryTracer;
        }
        return null;
    }
}

==> apache-camel-quarkus-3.30.0-src.zip: camel-quarkus-3.30.0/extensions/opentelemetry2/runtime/src/main/java/org/apache/camel/quarkus/component/opentelemetry2/OpenTelemetry2TracerProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.opentelemetry2;

import io.quarkus.arc.DefaultBean;
import io.quarkus.opentelemetry.runtime.config.runtime.OTelRuntimeConfig;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Inject;
import jakarta.inject.Singleton;
import org.apache.camel.CamelContext;
import org.apache.camel.opentelemetry2.OpenTelemetryTracer;

@Singleton
public class OpenTelemetry2TracerProducer {

    @Inject
    CamelOpenTelemetry2Config config;

    @Inject
    OTelRuntimeConfig oTelRuntimeConfig;

    @Produces
    @Singleton
    @DefaultBean
    public OpenTelemetryTracer getOpenTelemetry(CamelContext camelContext) {
        if (!oTelRuntimeConfig.sdkDisabled()) {
            OpenTelemetryTracer openTelemetryTracer = new OpenTelemetryTracer();
            if (config.excludePatterns().isPresent()) {
                openTelemetryTracer.setExcludePatterns(config.excludePatterns().get());
            }

            if (config.traceProcessors()) {
                openTelemetryTracer.setTraceProcessors(config.traceProcessors());
            }

            openTelemetryTracer.init(camelContext);

            return openTelemetryTracer;
        }
        return null;
    }
}
